@@ -816,7 +816,7 @@ class Decoder(srd.Decoder):
     name = 'Modbus'
     longname = 'Modbus RTU over RS232/RS485'
     desc = 'Modbus RTU protocol for industrial applications.'
-    license = 'gplv2+'
+    license = 'gplv3+'
     inputs = ['uart']
     outputs = ['modbus']
     annotations = (
@@ -846,7 +846,7 @@ class Decoder(srd.Decoder):
             'values': ('RX', 'TX')},
     )
 
-    def __init__(self, **kwargs):
+    def __init__(self):
         self.ADUSc = None # Start off with empty slave -> client ADU.
         self.ADUCs = None # Start off with empty client -> slave ADU.
 
